#
# spec file for package vlmc.spec
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define vlcpp_ver 0.1.0+git110.g0c00299
%define medialib_ver 0~git1085
%define jpeg_ver 1.5.1

Name:           vlmc
Version:        0.2.0ff+git1355
Release:        2.1
Summary:        VideoLAN Movie Creator
License:        GPL-2.0+
Group:          Applications/Multimedia
Url:            https://www.videolan.org/vlmc/
Source0:        vlmc-%{version}.tar.xz
Source1:        libvlcpp-%{vlcpp_ver}.tar.xz
Source2:        medialibrary-%{medialib_ver}.tar.xz
Source3:        libjpeg-turbo-%{jpeg_ver}.tar.gz
Patch0:         libjpeg-turbo-1.3.0-tiff-ojpeg.patch
Patch1:         libjpeg-1.4.0-ocloexec.patch
Patch2:         vlmc.build-compare.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  desktop-file-utils
BuildRequires:  frei0r-plugins-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Qt5Core) >= 5.5
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.5
BuildRequires:  pkgconfig(Qt5Gui) >= 5.5
BuildRequires:  pkgconfig(Qt5Network) >= 5.5
BuildRequires:  pkgconfig(Qt5Quick) >= 5.5
BuildRequires:  pkgconfig(mlt-framework) >= 6.3
BuildRequires:  pkgconfig(mlt++) >= 6.3
%if 0%{?sle_version} == 120100
BuildRequires:  libjpeg8-devel
%else
%if 0%{?sle_version} == 120200
BuildRequires:  yasm
%else
Buildrequires:  pkgconfig(libjpeg)
%endif
%endif
BuildRequires:  pkgconfig(libvlc) >= 3.0
BuildRequires:  pkgconfig(sqlite3)
Requires:       frei0r-plugins
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
VideoLAN Movie Creator is a non-linear editing software for video creation based on libVLC

%prep
%setup -q -a 1 -a 2 -a 3
%patch2 -p1
%if 0%{?sle_version} == 120200
pushd libjpeg-turbo-%{jpeg_ver}
%patch0
%patch1
popd
%endif

%build
%if 0%{?sle_version} == 120200
export LIBJPEG_CFLAGS="-I%{_builddir}/%{name}-%{version}/libjpeg-turbo-%{jpeg_ver}"
export LIBJPEG_LIBS="-L%{_builddir}/%{name}-%{version}/libjpeg-turbo-%{jpeg_ver}/.libs -ljpeg"
pushd libjpeg-turbo-%{jpeg_ver}
./configure --enable-static=yes --enable-shared=no --with-jpeg8 --without-turbojpg
make %{?_smp_mflags}
popd
%else
export LIBJPEG_CFLAGS="-I%{_includedir}"
export LIBJPEG_LIBS="-L%{_libdir} -ljpeg"
%endif
pushd medialibrary-%{medialib_ver}
export CFLAGS="%{optflags} -I%{_builddir}/%{name}-%{version}/libvlcpp-%{vlcpp_ver}"
export CXXFLAGS="%{optflags} -I%{_builddir}/%{name}-%{version}/libvlcpp-%{vlcpp_ver}"
export VLCPP_CFLAGS="-I%{_builddir}/%{name}-%{version}/libvlcpp-%{vlcpp_ver}"
export VLCPP_LIBS="-L%{_builddir}/%{name}-%{version}/libvlcpp-%{vlcpp_ver}"
export MEDIALIBRARY_CFLAGS="-I%{_builddir}/%{name}-%{version}/medialibrary-%{medialib_ver}/include"
export MEDIALIBRARY_LIBS="-L%{_builddir}/%{name}-%{version}/medialibrary-%{medialib_ver}/.libs -lmedialibrary -lsqlite3 -lvlc $LIBJPEG_LIBS"
%if 0%{?suse_version} > 1320
export MEDIALIBRARY_LIBS="$MEDIALIBRARY_LIBS -lpthread"
%endif
./bootstrap
./configure --enable-static --disable-shared
make %{?_smp_mflags}
popd
./bootstrap
%configure
make VERBOSE=1 %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -m 0644 doc/vlmc.1 -t %{buildroot}%{_mandir}/man1
install -m 0644 share/vlmc.desktop -t %{buildroot}%{_datadir}/applications
install -m 0644 share/vlmc.png -t %{buildroot}%{_datadir}/pixmaps

desktop-file-validate \
  %{buildroot}%{_datadir}/applications/vlmc.desktop

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README.md TRANSLATORS
%{_bindir}/vlmc
%{_mandir}/man1/vlmc.1.*
%{_datadir}/applications/vlmc.desktop
%{_datadir}/pixmaps/vlmc.png

%changelog
* Tue Nov 15 2016 aloisio@gmx.com
- Update to current git version
- Dropped fix-return_nonvoid.patch
- Included libvlcpp-0.1.0+git110.g0c00299.tar.xz
  and medialibrary-0~git1085.tar.xz for static
  linking
- Included libjpeg-1.4.0-ocloexec.patch
  libjpeg-turbo-1.3.0-tiff-ojpeg.patch
  libjpeg-turbo-1.5.1.tar.gz for Leap 42.2
* Mon Feb 23 2015 aloisio@gmx.com
- Initial version 0.2.0+git20141230
